@@ -175,6 +175,10 @@ watch::Playlist::Track extract_watch_track(py::handle track) {
                 return std::nullopt;
             }
 
+            if (track["album"].is_none()) {
+                return std::nullopt;
+            }
+
             return extract_meta_album(track["album"]);
         }()
     };
@@ -272,16 +276,17 @@ std::optional<artist::Artist::Section<T>> extract_artist_section(py::handle arti
 
 std::optional<search::SearchResultItem> extract_search_result(py::handle result) {
     const auto resultType = result["resultType"].cast<std::string>();
+
     if (resultType == "video") {
         return search::Video {
             {
                 result["videoId"].cast<std::string>(),
                 result["title"].cast<std::string>(),
                 extract_py_list<meta::Artist>(result["artists"]),
-                result["views"].cast<std::string>(),
+                result["duration"].cast<std::string>(),
                 extract_py_list<meta::Thumbnail>(result["thumbnails"])
             },
-            result["duration"].cast<std::string>()
+            optional_key<std::string>(result, "views")
         };
     } else if (resultType == "song") {
         return search::Song {
@@ -292,7 +297,7 @@ std::optional<search::SearchResultItem> extract_search_result(py::handle result)
                 result["duration"].cast<std::string>(),
                 extract_py_list<meta::Thumbnail>(result["thumbnails"])
             },
-            extract_meta_album(result["album"]),
+            result["album"].is_none() ? std::optional<meta::Album> {} : extract_meta_album(result["album"]),
             result["isExplicit"].cast<bool>()
         };
     } else if (resultType == "album") {
@@ -357,6 +362,9 @@ std::vector<search::SearchResultItem> YTMusic::search(
 
     std::vector<search::SearchResultItem> output;
     for (const auto &result : results) {
+        if (result.is_none()) {
+            continue;
+        }
         if (const auto opt = extract_search_result(result); opt.has_value()) {
             output.push_back(opt.value());
         }
@@ -391,7 +399,7 @@ album::Album YTMusic::get_album(const std::string &browseId) const
         album["trackCount"].cast<int>(),
         album["duration"].cast<std::string>(),
         album["audioPlaylistId"].cast<std::string>(),
-        album["year"].cast<std::string>(),
+        optional_key<std::string>(album, "year"),
         optional_key<std::string>(album, "description"),
         extract_py_list<meta::Thumbnail>(album["thumbnails"]),
         extract_py_list<album::Track>(album["tracks"]),
